EKF SC9-TOCCATA — ekfsm documentation

# EKF SC9-TOCCATA

See Product Page for the board’s technical specifications.

## Inventory (Object: inventory)

The inventory function provides access to the inventory, such as the vendor, model, serial number (taken from the board’s EEPROM), and revision (from SMBIOS sysfs entry).

Method | Description | Example Value
`vendor()` | Get the board vendor | `EKF`
`model()` | Get the board model | `SC9-TOCCATA`
`serial()` | Get the board serial number | `12345678`
`repaired_at()` | Board repair date |
`repaired_at()` | Board manufacturing date |
`revision()` | Get the board revision | `1`

## CPU Temperature (Object: cputemp)

The CPU temperature object provides the current CPU Die temperature in degrees Celsius.

Method | Description | Example Value
`cputemp()` | Get the CPU temp | `65`